@@ -21,7 +21,12 @@
 #include <QVBoxLayout>
 
 #include <KIO/OpenUrlJob>
+#include <kio_version.h>
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
+#include <KIO/JobUiDelegateFactory>
+#else
 #include <KIO/JobUiDelegate>
+#endif
 #include <KGuiItem>
 #include <KIO/StatJob>
 #include <KIO/CopyJob>
@@ -197,7 +202,11 @@ void HighscoresWidget::handleUrlClicked()
     }
 //   kDebug(11001) ;
     auto *job = new KIO::OpenUrlJob(QUrl(label->url()));
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
+    job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+#else
     job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+#endif
     job->start();
 }
 
@@ -572,11 +581,11 @@ bool ConfigDialog::save()
          && !enabled ) return true;
 
     if ( newName.isEmpty() ) {
-        KMessageBox::sorry(this, i18n("Please choose a non empty nickname."));
+        KMessageBox::error(this, i18n("Please choose a non empty nickname."));
         return false;
     }
     if ( internal->playerInfos().isNameUsed(newName) ) {
-        KMessageBox::sorry(this, i18n("Nickname already in use. Please "
+        KMessageBox::error(this, i18n("Nickname already in use. Please "
                                       "choose another one"));
         return false;
     }
